@@ -41,24 +41,25 @@ let test_with_used_args = test "test_with_used_args"
 
 let default =
   let meta =
-    let open B0_meta in
-    empty
-    |> add authors ["The cmdliner programmers"]
-    |> add maintainers ["Daniel Bünzli <daniel.buenzl i@erratique.ch>"]
-    |> add homepage "https://erratique.ch/software/cmdliner"
-    |> add online_doc "https://erratique.ch/software/cmdliner/doc"
-    |> add issues "https://github.com/dbuenzli/cmdliner/issues"
-    |> add repo "git+https://erratique.ch/repos/cmdliner.git"
-    |> add licenses ["ISC"]
-    |> add description_tags ["cli"; "system"; "declarative"; "org:erratique"]
-    |> tag B0_opam.tag
-    |> add B0_opam.Meta.depends
+    B0_meta.empty
+    |> B0_meta.(add authors) ["The cmdliner programmers"]
+    |> B0_meta.(add maintainers)
+       ["Daniel Bünzli <daniel.buenzl i@erratique.ch>"]
+    |> B0_meta.(add homepage) "https://erratique.ch/software/cmdliner"
+    |> B0_meta.(add online_doc) "https://erratique.ch/software/cmdliner/doc"
+    |> B0_meta.(add issues) "https://github.com/dbuenzli/cmdliner/issues"
+    |> B0_meta.(add repo) "git+https://erratique.ch/repos/cmdliner.git"
+    |> B0_meta.(add licenses) ["ISC"]
+    |> B0_meta.(add description_tags)
+       ["cli"; "system"; "declarative"; "org:erratique"]
+    |> B0_meta.tag B0_opam.tag
+    |> B0_meta.add B0_opam.depends
       [ "ocaml", {|>= "4.08.0"|}; ]
-    |> add B0_opam.Meta.build
+    |> B0_meta.add B0_opam.build
       {|[[ make "all" "PREFIX=%{prefix}%" ]]|}
-    |> add B0_opam.Meta.install
+    |> B0_meta.add B0_opam.install
       {|[[make "install" "LIBDIR=%{_:lib}%" "DOCDIR=%{_:doc}%"]
          [make "install-doc" "LIBDIR=%{_:lib}%" "DOCDIR=%{_:doc}%"]]|}
   in
-  B0_pack.v "default" ~doc:"cmdliner package" ~meta ~locked:true @@
+  B0_pack.make "default" ~doc:"cmdliner package" ~meta ~locked:true @@
   B0_unit.list ()
